@@ -1,4 +1,4 @@
-use inquire::Confirm;
+use inquire::{ui::RenderConfig, Confirm};
 
 fn main() {
     let ans = Confirm::new("Do you live in Brazil?")
@@ -18,6 +18,7 @@ fn main() {
     let ans = Confirm {
         message: "Are you happy?",
         default: Some(false),
+        placeholder: Some("si|no"),
         help_message: Some("It's alright if you're not"),
         formatter: Confirm::DEFAULT_FORMATTER,
         parser: &|ans| match ans {
@@ -30,6 +31,7 @@ fn main() {
             true => String::from("si"),
             false => String::from("no"),
         },
+        render_config: RenderConfig::default_static_ref(),
     }
     .prompt()
     .unwrap();
