@@ -8,10 +8,8 @@ use crate::{
     date_utils::{get_current_date, get_month},
     error::{InquireError, InquireResult},
     formatter::{self, DateFormatter},
-    ui::{
-        crossterm::CrosstermTerminal, date::DateSelectBackend, Backend, Key, KeyModifiers,
-        RenderConfig, Terminal,
-    },
+    terminal::{get_default_terminal, Terminal},
+    ui::{date::DateSelectBackend, Backend, Key, KeyModifiers, RenderConfig},
     validator::DateValidator,
 };
 
@@ -93,6 +91,13 @@ pub struct DateSelect<'a> {
     pub validators: Vec<DateValidator<'a>>,
 
     /// RenderConfig to apply to the rendered interface.
+    ///
+    /// Note: The default render config considers if the NO_COLOR environment variable
+    /// is set to decide whether to render the colored config or the empty one.
+    ///
+    /// When overriding the config in a prompt, NO_COLOR is no longer considered and your
+    /// config is treated as the only source of truth. If you want to customize colors
+    /// and still suport NO_COLOR, you will have to do this on your end.
     pub render_config: &'a RenderConfig,
 }
 
@@ -211,15 +216,39 @@ impl<'a> DateSelect<'a> {
     }
 
     /// Sets the provided color theme to this prompt.
+    ///
+    /// Note: The default render config considers if the NO_COLOR environment variable
+    /// is set to decide whether to render the colored config or the empty one.
+    ///
+    /// When overriding the config in a prompt, NO_COLOR is no longer considered and your
+    /// config is treated as the only source of truth. If you want to customize colors
+    /// and still suport NO_COLOR, you will have to do this on your end.
     pub fn with_render_config(mut self, render_config: &'a RenderConfig) -> Self {
         self.render_config = render_config;
         self
     }
 
+    /// Parses the provided behavioral and rendering options and prompts
+    /// the CLI user for input according to the defined rules.
+    ///
+    /// This method is intended for flows where the user skipping/cancelling
+    /// the prompt - by pressing ESC - is considered normal behavior. In this case,
+    /// it does not return `Err(InquireError::OperationCanceled)`, but `Ok(None)`.
+    ///
+    /// Meanwhile, if the user does submit an answer, the method wraps the return
+    /// type with `Some`.
+    pub fn prompt_skippable(self) -> InquireResult<Option<NaiveDate>> {
+        match self.prompt() {
+            Ok(answer) => Ok(Some(answer)),
+            Err(InquireError::OperationCanceled) => Ok(None),
+            Err(err) => Err(err),
+        }
+    }
+
     /// Parses the provided behavioral and rendering options and prompts
     /// the CLI user for input according to the defined rules.
     pub fn prompt(self) -> InquireResult<NaiveDate> {
-        let terminal = CrosstermTerminal::new()?;
+        let terminal = get_default_terminal()?;
         let mut backend = Backend::new(terminal, self.render_config)?;
         self.prompt_with_backend(&mut backend)
     }
@@ -392,7 +421,8 @@ impl<'a> DateSelectPrompt<'a> {
             let key = backend.read_key()?;
 
             match key {
-                Key::Cancel => return Err(InquireError::OperationCanceled),
+                Key::Interrupt => interrupt_prompt!(),
+                Key::Cancel => cancel_prompt!(backend, &self.message),
                 Key::Submit | Key::Char(' ', _) => match self.get_final_answer() {
                     Ok(answer) => {
                         final_answer = answer;
@@ -406,22 +436,21 @@ impl<'a> DateSelectPrompt<'a> {
 
         let formatted = (self.formatter)(final_answer);
 
-        backend.finish_prompt(&self.message, &formatted)?;
-
-        Ok(final_answer)
+        finish_prompt_with_answer!(backend, &self.message, &formatted, final_answer);
     }
 }
 
 #[cfg(test)]
+#[cfg(feature = "crossterm")]
 mod test {
     use crate::{
         date_utils::get_current_date,
-        ui::{crossterm::CrosstermTerminal, Backend, RenderConfig},
+        terminal::crossterm::CrosstermTerminal,
+        ui::{Backend, RenderConfig},
         DateSelect,
     };
     use chrono::NaiveDate;
     use crossterm::event::{KeyCode, KeyEvent};
-    use ntest::timeout;
 
     fn default<'a>() -> DateSelect<'a> {
         DateSelect::new("Question?")
@@ -434,7 +463,6 @@ mod test {
 
         ($name:ident,$input:expr,$output:expr,$prompt:expr) => {
             #[test]
-            #[timeout(100)]
             fn $name() {
                 let read: Vec<KeyEvent> = $input.into_iter().map(KeyEvent::from).collect();
                 let mut read = read.iter();
@@ -461,7 +489,6 @@ mod test {
     );
 
     #[test]
-    #[timeout(100)]
     /// Tests that a closure that actually closes on a variable can be used
     /// as a DateSelect validator.
     fn closure_validator() {
