@@ -6,7 +6,8 @@ use crate::{
     formatter::OptionFormatter,
     input::Input,
     list_option::ListOption,
-    ui::{crossterm::CrosstermTerminal, Backend, Key, KeyModifiers, RenderConfig, SelectBackend},
+    terminal::get_default_terminal,
+    ui::{Backend, Key, KeyModifiers, RenderConfig, SelectBackend},
     utils::paginate,
 };
 
@@ -30,6 +31,7 @@ use crate::{
 /// - **Formatter**: Custom formatter in case you need to pre-process the user input before showing it as the final answer.
 ///   - Prints the selected option string value by default.
 /// - **Page size**: Number of options displayed at once, 7 by default.
+/// - **Display option indexes**: On long lists, it might be helpful to display the indexes of the options to the user. Via the `RenderConfig`, you can set the display mode of the indexes as a prefix of an option. The default configuration is `None`, to not render any index when displaying the options.
 /// - **Filter function**: Function that defines if an option is displayed or not based on the current filter input.
 ///
 /// # Example
@@ -79,6 +81,13 @@ pub struct Select<'a, T> {
     pub formatter: OptionFormatter<'a, T>,
 
     /// RenderConfig to apply to the rendered interface.
+    ///
+    /// Note: The default render config considers if the NO_COLOR environment variable
+    /// is set to decide whether to render the colored config or the empty one.
+    ///
+    /// When overriding the config in a prompt, NO_COLOR is no longer considered and your
+    /// config is treated as the only source of truth. If you want to customize colors
+    /// and still suport NO_COLOR, you will have to do this on your end.
     pub render_config: &'a RenderConfig,
 }
 
@@ -201,6 +210,13 @@ where
     }
 
     /// Sets the provided color theme to this prompt.
+    ///
+    /// Note: The default render config considers if the NO_COLOR environment variable
+    /// is set to decide whether to render the colored config or the empty one.
+    ///
+    /// When overriding the config in a prompt, NO_COLOR is no longer considered and your
+    /// config is treated as the only source of truth. If you want to customize colors
+    /// and still suport NO_COLOR, you will have to do this on your end.
     pub fn with_render_config(mut self, render_config: &'a RenderConfig) -> Self {
         self.render_config = render_config;
         self
@@ -214,13 +230,30 @@ where
         self.raw_prompt().map(|op| op.value)
     }
 
+    /// Parses the provided behavioral and rendering options and prompts
+    /// the CLI user for input according to the defined rules.
+    ///
+    /// This method is intended for flows where the user skipping/cancelling
+    /// the prompt - by pressing ESC - is considered normal behavior. In this case,
+    /// it does not return `Err(InquireError::OperationCanceled)`, but `Ok(None)`.
+    ///
+    /// Meanwhile, if the user does submit an answer, the method wraps the return
+    /// type with `Some`.
+    pub fn prompt_skippable(self) -> InquireResult<Option<T>> {
+        match self.prompt() {
+            Ok(answer) => Ok(Some(answer)),
+            Err(InquireError::OperationCanceled) => Ok(None),
+            Err(err) => Err(err),
+        }
+    }
+
     /// Parses the provided behavioral and rendering options and prompts
     /// the CLI user for input according to the defined rules.
     ///
     /// Returns a [`ListOption`](crate::list_option::ListOption) containing
     /// the index of the selection and the owned object selected by the user.
     pub fn raw_prompt(self) -> InquireResult<ListOption<T>> {
-        let terminal = CrosstermTerminal::new()?;
+        let terminal = get_default_terminal()?;
         let mut backend = Backend::new(terminal, self.render_config)?;
         self.prompt_with_backend(&mut backend)
     }
@@ -312,7 +345,9 @@ where
         self.cursor_index = self.cursor_index.saturating_add(qty);
 
         if self.cursor_index >= self.filtered_options.len() {
-            self.cursor_index = if wrap {
+            self.cursor_index = if self.filtered_options.is_empty() {
+                0
+            } else if wrap {
                 self.cursor_index % self.filtered_options.len()
             } else {
                 self.filtered_options.len().saturating_sub(1)
@@ -394,7 +429,8 @@ where
             let key = backend.read_key()?;
 
             match key {
-                Key::Cancel => return Err(InquireError::OperationCanceled),
+                Key::Interrupt => interrupt_prompt!(),
+                Key::Cancel => cancel_prompt!(backend, &self.message),
                 Key::Submit => match self.has_answer_highlighted() {
                     true => break,
                     false => {}
@@ -406,18 +442,18 @@ where
         let final_answer = self.get_final_answer();
         let formatted = (self.formatter)(final_answer.as_ref());
 
-        backend.finish_prompt(&self.message, &formatted)?;
-
-        Ok(final_answer)
+        finish_prompt_with_answer!(backend, &self.message, &formatted, final_answer);
     }
 }
 
 #[cfg(test)]
+#[cfg(feature = "crossterm")]
 mod test {
     use crate::{
         formatter::OptionFormatter,
         list_option::ListOption,
-        ui::{crossterm::CrosstermTerminal, Backend, RenderConfig},
+        terminal::crossterm::CrosstermTerminal,
+        ui::{Backend, RenderConfig},
         Select,
     };
     use crossterm::event::{KeyCode, KeyEvent};
@@ -450,8 +486,8 @@ mod test {
     }
 
     #[test]
-    // https://github.com/mikaelmello/inquire/issues/29
-    fn regression_29() {
+    // Anti-regression test: https://github.com/mikaelmello/inquire/issues/29
+    fn enter_arrow_on_empty_list_does_not_panic() {
         let read: Vec<KeyEvent> = [
             KeyCode::Char('9'),
             KeyCode::Enter,
@@ -477,4 +513,35 @@ mod test {
 
         assert_eq!(ListOption::new(2, 3), ans);
     }
+
+    #[test]
+    // Anti-regression test: https://github.com/mikaelmello/inquire/issues/30
+    fn down_arrow_on_empty_list_does_not_panic() {
+        let read: Vec<KeyEvent> = [
+            KeyCode::Char('9'),
+            KeyCode::Down,
+            KeyCode::Backspace,
+            KeyCode::Char('3'),
+            KeyCode::Down,
+            KeyCode::Backspace,
+            KeyCode::Enter,
+        ]
+        .iter()
+        .map(|c| KeyEvent::from(*c))
+        .collect();
+
+        let mut read = read.iter();
+
+        let options = vec![1, 2, 3];
+
+        let mut write: Vec<u8> = Vec::new();
+        let terminal = CrosstermTerminal::new_with_io(&mut write, &mut read);
+        let mut backend = Backend::new(terminal, RenderConfig::default_static_ref()).unwrap();
+
+        let ans = Select::new("Question", options)
+            .prompt_with_backend(&mut backend)
+            .unwrap();
+
+        assert_eq!(ListOption::new(0, 1), ans);
+    }
 }
