@@ -1,3 +1,5 @@
+use std::env;
+
 use lazy_static::lazy_static;
 
 use super::{Color, StyleSheet, Styled};
@@ -18,7 +20,7 @@ use super::{Color, StyleSheet, Styled};
 ///
 /// let default_used_in_prompts: &'static RenderConfig = RenderConfig::default_static_ref();
 ///
-/// let prompt_prefix = Styled::new("$").with_fg(Color::Red);
+/// let prompt_prefix = Styled::new("$").with_fg(Color::DarkRed);
 /// let mine = default.with_prompt_prefix(prompt_prefix);
 /// ```
 #[derive(Clone, Debug)]
@@ -46,13 +48,6 @@ pub struct RenderConfig {
     /// and after the default value, as separators.
     pub placeholder: StyleSheet,
 
-    /// Render configuration of placeholder cursors.
-    ///
-    /// Note: placeholders are displayed wrapped in parenthesis, e.g. (yes).
-    /// Non-styled space characters is added before the default value display
-    /// and after the default value, as separators.
-    pub placeholder_cursor: StyleSheet,
-
     /// Render configuration of help messages.
     ///
     /// Note: help messages are displayed wrapped in brackets, e.g. [Be careful!].
@@ -65,11 +60,11 @@ pub struct RenderConfig {
     /// [`text_input`](crate::ui::RenderConfig::text_input) configuration.
     pub password_mask: char,
 
-    /// Render configuration of text inputs.
+    /// Style sheet for text inputs.
     ///
     /// Note: a non-styled space character is added before the text input as
     /// a separator from the prompt message (or default value display).
-    pub text_input: InputRenderConfig,
+    pub text_input: StyleSheet,
 
     /// Render configuration of final prompt answers (submissions).
     ///
@@ -77,6 +72,13 @@ pub struct RenderConfig {
     /// a separator from the prompt message (or default value display).
     pub answer: StyleSheet,
 
+    /// Render configuration of the message printed in the place of an answer
+    /// when the prompt is canceled by the user - by pressing ESC.
+    ///
+    /// Note: a non-styled space character is added before the indicator as
+    /// a separator from the prompt message.
+    pub canceled_prompt_indicator: Styled<&'static str>,
+
     /// Render configuration for error messages.
     pub error_message: ErrorMessageRenderConfig,
 
@@ -114,6 +116,9 @@ pub struct RenderConfig {
     /// option value to the right.
     pub unselected_checkbox: Styled<&'static str>,
 
+    /// Definition of index prefixes in option lists.
+    pub option_index_prefix: IndexPrefix,
+
     /// Style sheet for options.
     ///
     /// Note: a non-styled space character is added before the option value as
@@ -123,7 +128,15 @@ pub struct RenderConfig {
     /// Render configuration for calendar
 
     #[cfg(feature = "date")]
+    /// Render configuration for date prompts.
     pub calendar: calendar::CalendarRenderConfig,
+
+    /// Style sheet of the hint in editor prompts.
+    ///
+    /// The hint is formatted as `[(e) to open {}, (enter) to submit]`
+    /// with the editor name.
+    #[cfg(feature = "editor")]
+    pub editor_prompt: StyleSheet,
 }
 
 impl RenderConfig {
@@ -134,21 +147,54 @@ impl RenderConfig {
             prompt: StyleSheet::empty(),
             default_value: StyleSheet::empty(),
             placeholder: StyleSheet::empty(),
-            placeholder_cursor: StyleSheet::empty(),
             help_message: StyleSheet::empty(),
-            text_input: InputRenderConfig::empty(),
+            text_input: StyleSheet::empty(),
             error_message: ErrorMessageRenderConfig::empty(),
             answer: StyleSheet::empty(),
+            canceled_prompt_indicator: Styled::new("<canceled>"),
             password_mask: '*',
             highlighted_option_prefix: Styled::new(">"),
             scroll_up_prefix: Styled::new("^"),
             scroll_down_prefix: Styled::new("v"),
             selected_checkbox: Styled::new("[x]"),
             unselected_checkbox: Styled::new("[ ]"),
+            option_index_prefix: IndexPrefix::None,
             option: StyleSheet::empty(),
 
             #[cfg(feature = "date")]
             calendar: calendar::CalendarRenderConfig::empty(),
+
+            #[cfg(feature = "editor")]
+            editor_prompt: StyleSheet::empty(),
+        }
+    }
+
+    /// RenderConfig where default colors and attributes are applied.
+    pub fn default_colored() -> Self {
+        Self {
+            prompt_prefix: Styled::new("?").with_fg(Color::LightGreen),
+            prompt: StyleSheet::empty(),
+            default_value: StyleSheet::empty(),
+            placeholder: StyleSheet::new().with_fg(Color::DarkGrey),
+            help_message: StyleSheet::empty().with_fg(Color::LightCyan),
+            text_input: StyleSheet::empty(),
+            error_message: ErrorMessageRenderConfig::default_colored(),
+            password_mask: '*',
+            answer: StyleSheet::empty().with_fg(Color::LightCyan),
+            canceled_prompt_indicator: Styled::new("<canceled>").with_fg(Color::DarkRed),
+            highlighted_option_prefix: Styled::new(">").with_fg(Color::LightCyan),
+            scroll_up_prefix: Styled::new("^"),
+            scroll_down_prefix: Styled::new("v"),
+            selected_checkbox: Styled::new("[x]").with_fg(Color::LightGreen),
+            unselected_checkbox: Styled::new("[ ]"),
+            option_index_prefix: IndexPrefix::None,
+            option: StyleSheet::empty(),
+
+            #[cfg(feature = "date")]
+            calendar: calendar::CalendarRenderConfig::default_colored(),
+
+            #[cfg(feature = "editor")]
+            editor_prompt: StyleSheet::new().with_fg(Color::DarkCyan),
         }
     }
 
@@ -176,8 +222,8 @@ impl RenderConfig {
         self
     }
 
-    /// Sets the text input render configuration.
-    pub fn with_text_input(mut self, text_input: InputRenderConfig) -> Self {
+    /// Sets style for text inputs.
+    pub fn with_text_input(mut self, text_input: StyleSheet) -> Self {
         self.text_input = text_input;
         self
     }
@@ -239,94 +285,87 @@ impl RenderConfig {
         self
     }
 
+    /// Sets the index prefix for option lists.
+    pub fn with_option_index_prefix(mut self, index_prefix: IndexPrefix) -> Self {
+        self.option_index_prefix = index_prefix;
+        self
+    }
+
     /// Sets the style sheet for option values.
     pub fn with_option(mut self, option: StyleSheet) -> Self {
         self.option = option;
         self
     }
 
+    /// Sets the indicator for canceled prompts.
+    pub fn with_canceled_prompt_indicator(
+        mut self,
+        canceled_prompt_indicator: Styled<&'static str>,
+    ) -> Self {
+        self.canceled_prompt_indicator = canceled_prompt_indicator;
+        self
+    }
+
     #[cfg(feature = "date")]
     /// Sets the render configuration for calendars.
     pub fn with_calendar_config(mut self, calendar: calendar::CalendarRenderConfig) -> Self {
         self.calendar = calendar;
         self
     }
+
+    #[cfg(feature = "editor")]
+    /// Sets the render configuration for editor prompts.
+    pub fn with_editor_prompt(mut self, editor_prompt: StyleSheet) -> Self {
+        self.editor_prompt = editor_prompt;
+        self
+    }
 }
 
 impl Default for RenderConfig {
     fn default() -> Self {
-        Self {
-            prompt_prefix: Styled::new("?").with_fg(Color::Green),
-            prompt: StyleSheet::empty(),
-            default_value: StyleSheet::empty(),
-            placeholder: StyleSheet::new().with_fg(Color::DarkGrey),
-            placeholder_cursor: StyleSheet::new()
-                .with_fg(Color::Black)
-                .with_bg(Color::DarkGrey),
-            help_message: StyleSheet::empty().with_fg(Color::Cyan),
-            text_input: InputRenderConfig::default(),
-            error_message: ErrorMessageRenderConfig::default(),
-            password_mask: '*',
-            answer: StyleSheet::empty().with_fg(Color::Cyan),
-            highlighted_option_prefix: Styled::new(">").with_fg(Color::Cyan),
-            scroll_up_prefix: Styled::new("^"),
-            scroll_down_prefix: Styled::new("v"),
-            selected_checkbox: Styled::new("[x]").with_fg(Color::Green),
-            unselected_checkbox: Styled::new("[ ]"),
-            option: StyleSheet::empty(),
-
-            #[cfg(feature = "date")]
-            calendar: calendar::CalendarRenderConfig::default(),
+        match env::var("NO_COLOR") {
+            Ok(_) => Self::empty(),
+            Err(_) => Self::default_colored(),
         }
     }
 }
 
-/// Render configuration for text inputs.
-///
-/// All text will be rendered with the `text`
-/// style sheet applied, except for the one character
-/// behind the cursor, which will have the `cursor`
-/// style sheet applied.
-#[derive(Clone, Debug)]
-pub struct InputRenderConfig {
-    /// Text style.
-    pub text: StyleSheet,
+/// Definition of index prefixes in option lists.
+#[derive(Copy, Clone, Debug, PartialEq)]
+pub enum IndexPrefix {
+    /// Lists of options will not display any hints regarding
+    /// the position/index of the positions.
+    None,
 
-    /// Cursor style.
-    pub cursor: StyleSheet,
-}
+    /// A simple index (1-based) will be displayed before the
+    /// option string representation.
+    Simple,
 
-impl InputRenderConfig {
-    /// Render configuration in which no colors or attributes are applied.
-    pub fn empty() -> Self {
-        Self {
-            text: StyleSheet::empty(),
-            cursor: StyleSheet::empty(),
-        }
-    }
+    /// A simple index (1-based) will be displayed before the
+    /// option string representation.
+    ///
+    /// The number representation of the index is padded with
+    /// spaces so that the length is the same of the largest
+    /// index. That is, if the list has 100 options, the first 9
+    /// options will be rendered as `"  1", "  2", ...`. Then all
+    /// indexes with two digits will be padded with one space, and
+    /// finally the last option with index 100 will not need to be
+    /// padded.
+    /// ```
+    SpacePadded,
 
-    /// Sets the text stylesheet.
-    pub fn with_text(mut self, text: StyleSheet) -> Self {
-        self.text = text;
-        self
-    }
-
-    /// Sets the cursor stylesheet.
-    pub fn with_cursor(mut self, cursor: StyleSheet) -> Self {
-        self.cursor = cursor;
-        self
-    }
-}
-
-impl Default for InputRenderConfig {
-    fn default() -> Self {
-        Self {
-            text: StyleSheet::empty(),
-            cursor: StyleSheet::empty()
-                .with_bg(Color::Grey)
-                .with_fg(Color::Black),
-        }
-    }
+    /// A simple index (1-based) will be displayed before the
+    /// option string representation.
+    ///
+    /// The number representation of the index is padded with
+    /// zeroes so that the length is the same of the largest
+    /// index. That is, if the list has 100 options, the first 9
+    /// options will be rendered as `"001", "002", ...`. Then all
+    /// indexes with two digits will be padded with one zero, and
+    /// finally the last option with index 100 will not need to be
+    /// padded.
+    /// ```
+    ZeroPadded,
 }
 
 /// Render configuration for error messages.
@@ -355,6 +394,15 @@ impl ErrorMessageRenderConfig {
         }
     }
 
+    /// Render configuration where default colors and attributes are applied.
+    pub fn default_colored() -> Self {
+        Self {
+            prefix: Styled::new("#").with_fg(Color::LightRed),
+            separator: StyleSheet::empty(),
+            message: StyleSheet::empty().with_fg(Color::LightRed),
+        }
+    }
+
     /// Sets the prefix.
     pub fn with_prefix(mut self, prefix: Styled<&'static str>) -> Self {
         self.prefix = prefix;
@@ -377,18 +425,10 @@ impl ErrorMessageRenderConfig {
     }
 }
 
-impl Default for ErrorMessageRenderConfig {
-    fn default() -> Self {
-        Self {
-            prefix: Styled::new("#").with_fg(Color::Red),
-            separator: StyleSheet::empty(),
-            message: StyleSheet::empty().with_fg(Color::Red),
-        }
-    }
-}
-
 #[cfg(feature = "date")]
-mod calendar {
+pub mod calendar {
+    //! Module containing additional render config for date prompts.
+
     use super::{Color, StyleSheet, Styled};
 
     /// Calendar configuration for error messages.
@@ -404,7 +444,14 @@ mod calendar {
         pub week_header: StyleSheet,
 
         /// Style sheet for the currently selected date.
-        pub selected_date: StyleSheet,
+        ///
+        /// When `None`, no custom style sheet will be applied and the native
+        /// terminal cursor will be used in the first char of the date number.
+        ///
+        /// Whem `Some(_)`, the style sheet will be applied to the two columns
+        /// where the number is positioned, padded to spaces in the left if the
+        /// number only has one digit. e.g. " 5" or "23".
+        pub selected_date: Option<StyleSheet>,
 
         /// Style sheet for today's date, just for hinting purposes.
         pub today_date: StyleSheet,
@@ -425,33 +472,34 @@ mod calendar {
                 prefix: Styled::new(">"),
                 header: StyleSheet::empty(),
                 week_header: StyleSheet::empty(),
-                selected_date: StyleSheet::empty(),
+                selected_date: None,
                 today_date: StyleSheet::empty(),
                 different_month_date: StyleSheet::empty(),
                 unavailable_date: StyleSheet::empty(),
             }
         }
 
+        /// Render configuration where default colors and attributes are applied.
+        pub fn default_colored() -> Self {
+            Self {
+                prefix: Styled::new(">").with_fg(Color::LightGreen),
+                header: StyleSheet::empty(),
+                week_header: StyleSheet::empty(),
+                selected_date: Some(
+                    StyleSheet::empty()
+                        .with_fg(Color::Black)
+                        .with_bg(Color::Grey),
+                ),
+                today_date: StyleSheet::empty().with_fg(Color::LightGreen),
+                different_month_date: StyleSheet::empty().with_fg(Color::DarkGrey),
+                unavailable_date: StyleSheet::empty().with_fg(Color::DarkGrey),
+            }
+        }
+
         /// Sets the prefix.
         pub fn with_prefix(mut self, prefix: Styled<&'static str>) -> Self {
             self.prefix = prefix;
             self
         }
     }
-
-    impl Default for CalendarRenderConfig {
-        fn default() -> Self {
-            Self {
-                prefix: Styled::new(">").with_fg(Color::Green),
-                header: StyleSheet::empty(),
-                week_header: StyleSheet::empty(),
-                selected_date: StyleSheet::empty()
-                    .with_fg(Color::Black)
-                    .with_bg(Color::Grey),
-                today_date: StyleSheet::empty().with_fg(Color::Green),
-                different_month_date: StyleSheet::empty().with_fg(Color::DarkGrey),
-                unavailable_date: StyleSheet::empty().with_fg(Color::DarkGrey),
-            }
-        }
-    }
 }
